==> haskell-xml-1.3.14-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xml
version:              1.3.14
visibility:           public
id:                   xml-1.3.14-A6bMPsWCgyp2aJRE11Eckt
key:                  xml-1.3.14-A6bMPsWCgyp2aJRE11Eckt
license:              BSD-3-Clause
copyright:            (c) 2007-2008 Galois Inc.
maintainer:           diatchki@galois.com
author:               Galois Inc.
homepage:             http://code.galois.com
synopsis:             A simple XML library.
description:          A simple XML library.
category:             Text, XML
abi:                  d97bdc04080880e46396407f44e74560
exposed:              True
exposed-modules:
    Text.XML.Light Text.XML.Light.Cursor Text.XML.Light.Input
    Text.XML.Light.Lexer Text.XML.Light.Output Text.XML.Light.Proc
    Text.XML.Light.Types

import-dirs:          /usr/lib/ghc-8.8.1/site-local/xml-1.3.14
library-dirs:         /usr/lib/ghc-8.8.1/site-local/xml-1.3.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/xml-1.3.14
hs-libraries:         HSxml-1.3.14-A6bMPsWCgyp2aJRE11Eckt
depends:              base-4.13.0.0 bytestring-0.10.9.0 text-1.2.4.0
haddock-interfaces:   /usr/share/doc/haskell-xml/html/xml.haddock
haddock-html:         /usr/share/doc/haskell-xml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-1.3.14-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xml
version:              1.3.14
visibility:           public
id:                   xml-1.3.14-IT4S7IkihY28IGBFVjHe4u
key:                  xml-1.3.14-IT4S7IkihY28IGBFVjHe4u
license:              BSD-3-Clause
copyright:            (c) 2007-2008 Galois Inc.
maintainer:           diatchki@galois.com
author:               Galois Inc.
homepage:             http://code.galois.com
synopsis:             A simple XML library.
description:          A simple XML library.
category:             Text, XML
abi:                  86a4d0cb29f5a0328c52f0d949154cb7
exposed:              True
exposed-modules:
    Text.XML.Light Text.XML.Light.Cursor Text.XML.Light.Input
    Text.XML.Light.Lexer Text.XML.Light.Output Text.XML.Light.Proc
    Text.XML.Light.Types

import-dirs:          /usr/lib/ghc-8.8.2/site-local/xml-1.3.14
library-dirs:         /usr/lib/ghc-8.8.2/site-local/xml-1.3.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.2/xml-1.3.14
hs-libraries:         HSxml-1.3.14-IT4S7IkihY28IGBFVjHe4u
depends:              base-4.13.0.0 bytestring-0.10.10.0 text-1.2.4.0
haddock-interfaces:   /usr/share/doc/haskell-xml/html/xml.haddock
haddock-html:         /usr/share/doc/haskell-xml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
